Postoperative Library for Image Transformation (PostoLIT)

Postoperative Library for Image Transformation

Developed: Prof. Anatoly Postolit 
(doctor of technical Sciences, Professor, academician of the Russian Academy of transport),
Director of the company Smart Information Systems LTd)
e-mail: anat_post@mail.ru

This function library is designed for post-processing images and frame-by-frame processing of video files. 
Can be used in computer vision systems (fixation of violations of traffic rules, assessment of drivers skills 
and car control, control of unmanned vehicles, counting the number of the visitor in the public areas and 
passengers in public transport, in medicine, in the advertising business, agriculture, etc.).
This is the first version of the library, which will be further developed and expanded.


1.black_image(image)	

2.canny_edge_detector(image)	

3.get_video_param(file_input)	

4.gray_image(image)	

5.resize_height(image, height)	

6.resize_percent (image, percent)
	
7.resize_width(image, width)	

8.resize_wh(image, width, height)	

9.rotate_image_fs(image, corner)	

10.rotate_image_is(mat, angle)	

11.set_video_param(file_input, width, height)	

12.segment_image(image)	